#include <pg_query.h>
#include <pg_query_fingerprint.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#ifdef USE_VALGRIND
#define TEST_LOOPS 10
#else
#define TEST_LOOPS 1000
#endif

const char* query = "select ? as field_id \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ? \
    union all select ?";

const char *fingerprint = "fc5a0500dddc25aa";

int main() {
    size_t i;
    bool ret_code = 0;

    for (i = 0; i < TEST_LOOPS; i++) {
        PgQueryFingerprintResult result = pg_query_fingerprint(query);

        if (result.error) {
            ret_code = -1;
            printf("%s\n", result.error->message);
        } else if (strcmp(result.fingerprint_str, fingerprint) == 0) {
            printf(".");
        } else {
            ret_code = -1;
            printf("INVALID result, expected: %s\nactual: %s\nactual tokens: \n", fingerprint, result.fingerprint_str);
            pg_query_fingerprint_with_opts(query, true);
        }

        pg_query_free_fingerprint_result(result);

        if (ret_code != 0) break;
    }
    printf("\n");

    pg_query_exit();

    return ret_code;
}
